==> owncloud-app-calendar-1%3A1.2.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/README.md <==
# ownCloud Calendar 

[![Build Status](https://scrutinizer-ci.com/g/owncloud/calendar-rework/badges/build.png?b=master)](https://scrutinizer-ci.com/g/owncloud/calendar/build-status/master)
[![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/owncloud/calendar-rework/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/owncloud/calendar/?branch=master)
[![Code Coverage](https://scrutinizer-ci.com/g/owncloud/calendar-rework/badges/coverage.png?b=master)](https://scrutinizer-ci.com/g/owncloud/calendar/?branch=master)
[![Dependency Status](https://www.versioneye.com/user/projects/57333497a0ca35004cf77c92/badge.svg?style=flat)](https://www.versioneye.com/user/projects/57333497a0ca35004cf77c92)

**A calendar app for [ownCloud](https://owncloud.org).**  

This is the new calendar app that has replaced the [old calendar app](https://github.com/owncloudarchive/calendar) with ownCloud 9.0, and is only the frontend for the new CalDAV-Backend which has moved into the [ownCloud Core](https://github.com/owncloud/core). 

![](https://github.com/owncloud/screenshots/blob/master/calendar/screenshot.png)

## Maintainers:

 - [Georg Ehrke](https://github.com/georgehrke)
 - [Raghu Nayyar](https://github.com/raghunayyar)
 - [Bernhard Fröhler](https://github.com/codeling)

If you’d like to join, just go through the [issue list](https://github.com/owncloud/calendar/issues) and fix some. :)   
We’re also in [#owncloud-calendar on freenode IRC](https://webchat.freenode.net/?channels=owncloud-calendar).

## Support:

Check out our [FAQ](https://github.com/owncloud/calendar/wiki/FAQs). If you dont find a solution, you are welcome to [ask for support](https://owncloud.org/support/) in our Forums or the IRC-Channel. If you have found a bug, feel free to open a new Issue on GitHub. Keep in mind, that this repository only manages the frontend. If you find bugs or have problems with the CalDAV-Backend, you should ask the guys at [ownCloud Core](https://github.com/owncloud/core) for help!

## Supported Browsers

* Latest Firefox
* Latest Chrome/Chromium
* Latest Safari

We don't support Internet Explorer or Egde. Patches for IE8+ and Edge are accepted though.

==> owncloud-app-calendar-1%3A1.3.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/calendar/README.md <==
# ownCloud Calendar 

[![Build Status](https://travis-ci.org/owncloud/calendar.svg?branch=master)](https://travis-ci.org/owncloud/calendar)
[![Scrutinizer Code Quality](https://scrutinizer-ci.com/g/owncloud/calendar/badges/quality-score.png?b=master)](https://scrutinizer-ci.com/g/owncloud/calendar/?branch=master)
[![Code Coverage](https://scrutinizer-ci.com/g/owncloud/calendar/badges/coverage.png?b=master)](https://scrutinizer-ci.com/g/owncloud/calendar/?branch=master)
[![Coverage Status](https://coveralls.io/repos/github/owncloud/calendar/badge.svg?branch=master)](https://coveralls.io/github/owncloud/calendar?branch=master)
[![Dependency Status](https://www.versioneye.com/user/projects/57333497a0ca35004cf77c92/badge.svg?style=flat)](https://www.versioneye.com/user/projects/57333497a0ca35004cf77c92)

**A calendar app for [ownCloud](https://owncloud.org).**  

This is the new calendar app that has replaced the [old calendar app](https://github.com/owncloudarchive/calendar) with ownCloud 9.0, and is only the frontend for the new CalDAV-Backend which has moved into the [ownCloud Core](https://github.com/owncloud/core). 

![](https://github.com/owncloud/screenshots/blob/master/calendar/screenshot.png)

## Maintainers:

 - [Georg Ehrke](https://github.com/georgehrke)
 - [Raghu Nayyar](https://github.com/raghunayyar)
 - [Bernhard Fröhler](https://github.com/codeling)

If you’d like to join, just go through the [issue list](https://github.com/owncloud/calendar/issues) and fix some. :)   
We’re also in [#owncloud-calendar on freenode IRC](https://webchat.freenode.net/?channels=owncloud-calendar).

## Support:

Check out our [FAQ](https://github.com/owncloud/calendar/wiki/FAQs). If you dont find a solution, you are welcome to [ask for support](https://owncloud.org/support/) in our Forums or the IRC-Channel. If you have found a bug, feel free to open a new Issue on GitHub. Keep in mind, that this repository only manages the frontend. If you find bugs or have problems with the CalDAV-Backend, you should ask the guys at [ownCloud Core](https://github.com/owncloud/core) for help!

## Supported Browsers

* Latest Firefox
* Latest Chrome/Chromium
* Latest Safari

We don't support Internet Explorer or Egde. Patches for IE8+ and Edge are accepted though.
